summaryrefslogtreecommitdiff
path: root/troveclient/compat
diff options
context:
space:
mode:
authorSushil Kumar <sushil.kumar2@globallogic.com>2014-01-10 11:22:12 +0000
committerSushil Kumar <sushil.kumar2@globallogic.com>2014-01-14 03:39:07 +0000
commitd56111cb07f19fb23979921199d6961c130d22b3 (patch)
treef61c0491bc731bd717bb6d87e449b8b186b726a4 /troveclient/compat
parent1a704bef5550e2045da6d5cc2481fda7b708f77a (diff)
downloadpython-troveclient-d56111cb07f19fb23979921199d6961c130d22b3.tar.gz
Fixed misspellings of common words
Fixed misspelling of common words found by the 'misspellings' tool. Change-Id: I8e03379f92b62fd4856bbc74b7e4641226a403d3 Closes-Bug: #1257531
Diffstat (limited to 'troveclient/compat')
-rw-r--r--troveclient/compat/cli.py2
-rw-r--r--troveclient/compat/common.py4
-rw-r--r--troveclient/compat/tests/test_auth.py8
-rw-r--r--troveclient/compat/xml.py2
4 files changed, 8 insertions, 8 deletions
diff --git a/troveclient/compat/cli.py b/troveclient/compat/cli.py
index 892f8b8..54c9221 100644
--- a/troveclient/compat/cli.py
+++ b/troveclient/compat/cli.py
@@ -35,7 +35,7 @@ from troveclient.compat import common
class InstanceCommands(common.AuthedCommandsBase):
- """Commands to perform various instances operations and actions"""
+ """Commands to perform various instance operations and actions"""
params = [
'flavor',
diff --git a/troveclient/compat/common.py b/troveclient/compat/common.py
index 0cfbd9e..11853c3 100644
--- a/troveclient/compat/common.py
+++ b/troveclient/compat/common.py
@@ -365,7 +365,7 @@ class Auth(CommandsBase):
self.token = self.dbaas.client.auth_token
self.service_url = self.dbaas.client.service_url
CliOptions.save_from_instance_fields(self)
- print("Token aquired! Saving to %s..." % CliOptions.APITOKEN)
+ print("Token acquired! Saving to %s..." % CliOptions.APITOKEN)
print(" service_url = %s" % self.service_url)
print(" token = %s" % self.token)
except Exception:
@@ -375,7 +375,7 @@ class Auth(CommandsBase):
class AuthedCommandsBase(CommandsBase):
- """Commands that work only with an authicated client."""
+ """Commands that work only with an authenticated client."""
def __init__(self, parser):
"""Makes sure a token is available somehow and logs in."""
diff --git a/troveclient/compat/xml.py b/troveclient/compat/xml.py
index 2ea39b1..59ec8e1 100644
--- a/troveclient/compat/xml.py
+++ b/troveclient/compat/xml.py
@@ -254,7 +254,7 @@ def populate_element_from_dict(element, dict):
def modify_response_types(value, type_translator):
"""
This will convert some string in response dictionary to ints or bool
- so that our respose is compatible with code expecting JSON style responses
+ so that our response is compatible with code expecting JSON style responses
"""
if isinstance(value, str):
if value == 'True':
diff --git a/troveclient/compat/tests/test_auth.py b/troveclient/compat/tests/test_auth.py
index 582e000..b9ff105 100644
--- a/troveclient/compat/tests/test_auth.py
+++ b/troveclient/compat/tests/test_auth.py
@@ -330,7 +330,7 @@ class ServiceCatalogTest(testtools.TestCase):
self.case_no_endpoint_match(scObj)
# case for empty service catalog
- self.case_endpoing_with_empty_catalog(scObj)
+ self.case_endpoint_with_empty_catalog(scObj)
# more than one matching endpoints
self.case_ambiguous_endpoint(scObj)
@@ -368,9 +368,9 @@ class ServiceCatalogTest(testtools.TestCase):
self.assertRaises(exceptions.EndpointNotFound, scObj._url_for,
attr="test_attr", filter_value=filter_value)
- def case_endpoing_with_empty_catalog(self, scObj):
- # first, test with empty catalog, this should pass since
- # there is already enpoint added
+ def case_endpoint_with_empty_catalog(self, scObj):
+ # First, test with an empty catalog. This should pass since
+ # there is already an endpoint added.
scObj.catalog[scObj.root_key]['serviceCatalog'] = list()
endpoint = scObj.catalog['endpoints'][0]